@@ -16,7 +16,7 @@ from .utils import *
 
 async def _get_client(ls: int):
     TonlibClient.enable_unaudited_binaries()
-    client = TonlibClient(ls_index=ls)
+    client = TonlibClient(ls_index=ls, verbosity_level=1)
     await client.init_tonlib()
     return client
 
@@ -26,6 +26,15 @@ def get_client(ls: int = 0) -> TonlibClient:
     return client
 
 
+def close_client(client: TonlibClient):
+    try:
+        asyncio.get_event_loop().run_until_complete(client.tonlib_wrapper.close())
+        return True
+    except:
+        return False
+
+
+
 def get_nft_owner(addr: str, client: TonlibClient = None):
     if not client:
         client = get_client(2)
@@ -52,25 +61,29 @@ def get_items(addresses: list, filename_with_nft_metadata=None, client: TonlibCl
     nft_items = []
 
     for i in range(ceil(len(addresses) / max_requests)):
-        if client and client.tonlib_wrapper._is_working:
-            asyncio.get_event_loop().run_until_complete(client.tonlib_wrapper.close())
-        client = get_client(ls)
+        if not client or not client.tonlib_wrapper._is_working:
+            close_client(client)
+            client = get_client(ls)
         tasks = []
         for addr in addresses[i * max_requests:min(len(addresses), max_requests * (i + 1))]:
-            tasks.append(get_item(client, addr, nft_items, items))
+            tasks.append(get_item(client, addr, nft_items, items, ls))
         # asyncio.set_event_loop(asyncio.SelectorEventLoop())
         try:
             asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks))
         except:
-            asyncio.get_event_loop().run_until_complete(client.tonlib_wrapper.close())
+            close_client(client)
             raise ton.tonlibjson.TonlibException
+
         print('DONE')
     if len(nft_items) < len(addresses):
         raise Exception('SCANNED NOT ALL ITEMS')
     return {"nft_items": nft_items}
 
 
-async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict = None):
+async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict = None, ls=0):
+    if not client.tonlib_wrapper._is_working:
+        close_client(client)
+        client = get_client(ls)
     account = await client.find_account(addr, preload_state=False)
     x = await account.get_nft_data()
     collection_address = x['collection_address'].to_string()
